# Chuck Quotes

Demo package to retrieve Chuck Norris quotes from webservice.

## Usage

```python
from chuckquotes import ChuckQuotes

quote_manager = ChuckQuotes()
quote = quote_manager.get_fact()

# Chuck Norris once challenged Lance Armstrong in a "Who has more testicles?" contest. Chuck Norris won by 5. 
```